# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class ObjectClassSearchActiveDirectoryPrincipalsEnum(object):

    """Implementation of the 'objectClass_SearchActiveDirectoryPrincipals' enum.

    TODO: type enum description here.

    Attributes:
        KUSER: TODO: type description here.
        KGROUP: TODO: type description here.
        KCOMPUTER: TODO: type description here.
        KWELLKNOWNPRINCIPAL: TODO: type description here.

    """

    KUSER = 'kUser'

    KGROUP = 'kGroup'

    KCOMPUTER = 'kComputer'

    KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'

